@@ -1,27 +1,34 @@
 package Dist::Zilla::Plugin::ModuleBuildTiny;
 {
-  $Dist::Zilla::Plugin::ModuleBuildTiny::VERSION = '0.003';
+  $Dist::Zilla::Plugin::ModuleBuildTiny::VERSION = '0.004';
 }
 
 use Moose;
 with qw/Dist::Zilla::Role::BuildPL Dist::Zilla::Role::TextTemplate Dist::Zilla::Role::PrereqSource/;
-use Module::Metadata;
 
 use Dist::Zilla::File::InMemory;
-
-use version;
-use MooseX::Types::Perl qw(VersionObject);
+use Module::Metadata;
+use MooseX::Types::Moose qw/Str/;
 
 has version => (
-	is  => 'rw',
-	isa => VersionObject,
+	is      => 'ro',
+	isa     => Str,
 	default => sub {
-		return Module::Metadata->new_from_module('Module::Build::Tiny')->version;
+		return Module::Metadata->new_from_module('Module::Build::Tiny')->version->stringify;
 	},
-	coerce => 1,
 );
 
-my $template = "use Module::Build::Tiny {{ \$version }};\nBuild_PL();\n";
+has minimum_perl => (
+	is      => 'ro',
+	isa     => Str,
+	lazy    => 1,
+	default => sub {
+		my $self = shift;
+		return $self->zilla->prereqs->requirements_for('runtime', 'requires')->requirements_for_module('perl') || '5.006'
+	},
+);
+
+my $template = "use {{ \$minimum_perl }};\nuse Module::Build::Tiny {{ \$version }};\nBuild_PL();\n";
 
 sub register_prereqs {
 	my ($self) = @_;
@@ -34,7 +41,7 @@ sub register_prereqs {
 sub setup_installer {
 	my ($self, $arg) = @_;
 
-	my $content = $self->fill_in_string($template, { version => $self->version });
+	my $content = $self->fill_in_string($template, { version => $self->version, minimum_perl => $self->minimum_perl });
 	my $file = Dist::Zilla::File::InMemory->new({ name => 'Build.PL', content => $content });
 	$self->add_file($file);
 
@@ -58,7 +65,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny - Build a Build.PL that uses Module::Build:
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
@@ -72,6 +79,12 @@ B<Optional:> Specify the minimum version of L<Module::Build::Tiny> to depend on.
 
 Defaults to the version installed on the author's perl installation
 
+=head2 minimum_perl
+
+B<Optional:> Specify the minimum version of perl to require in the F<Build.PL>.
+
+This is normally taken from dzils prereq metadata.
+
 =head1 AUTHOR
 
 Leon Timmermans <fawaka@gmail.com>
